You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@stdcxx.apache.org by se...@apache.org on 2007/09/28 22:57:41 UTC

svn commit: r580483 [16/42] - in /incubator/stdcxx/branches/4.2.0: ./ bin/ doc/ doc/stdlibref/ doc/stdlibug/ etc/config/ etc/config/src/ etc/config/windows/ etc/nls/charmaps/ etc/nls/posix/charmaps/ etc/nls/posix/src/ etc/nls/src/ examples/manual/ exam...

Modified: incubator/stdcxx/branches/4.2.0/etc/config/src/thread.h
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/src/thread.h?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/src/thread.h (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/src/thread.h Fri Sep 28 13:55:52 2007
@@ -1,3 +1,26 @@
+
+/***************************************************************************
+ *
+ * Licensed to the Apache Software  Foundation (ASF) under one or more
+ * contributor  license agreements.  See  the NOTICE  file distributed
+ * with  this  work  for  additional information  regarding  copyright
+ * ownership.   The ASF  licenses this  file to  you under  the Apache
+ * License, Version  2.0 (the  License); you may  not use  this file
+ * except in  compliance with the License.   You may obtain  a copy of
+ * the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the  License is distributed on an  "AS IS" BASIS,
+ * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+ * implied.   See  the License  for  the  specific language  governing
+ * permissions and limitations under the License.
+ *
+ * Copyright 1999-2007 Rogue Wave Software, Inc.
+ * 
+ **************************************************************************/
+
 #if defined (_WIN32)
 
 // definitions of Win32 POSIX compatibility layer functions

Modified: incubator/stdcxx/branches/4.2.0/etc/config/src/types.h
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/src/types.h?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/src/types.h (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/src/types.h Fri Sep 28 13:55:52 2007
@@ -1,5 +1,27 @@
 // definitions of the type_name() helper overloads
 
+/***************************************************************************
+ *
+ * Licensed to the Apache Software  Foundation (ASF) under one or more
+ * contributor  license agreements.  See  the NOTICE  file distributed
+ * with  this  work  for  additional information  regarding  copyright
+ * ownership.   The ASF  licenses this  file to  you under  the Apache
+ * License, Version  2.0 (the  License); you may  not use  this file
+ * except in  compliance with the License.   You may obtain  a copy of
+ * the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the  License is distributed on an  "AS IS" BASIS,
+ * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+ * implied.   See  the License  for  the  specific language  governing
+ * permissions and limitations under the License.
+ *
+ * Copyright 1999-2007 Rogue Wave Software, Inc.
+ * 
+ **************************************************************************/
+
 #define STRSTR(symbol)   #symbol
 #define STR(symbol)      STRSTR (symbol)
 #define DEFINE_TYPE_HELPER(T, symbol)                   \

Modified: incubator/stdcxx/branches/4.2.0/etc/config/sunpro.config
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/sunpro.config?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/sunpro.config (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/sunpro.config Fri Sep 28 13:55:52 2007
@@ -4,14 +4,34 @@
 #
 # configuration file for SunPro CC on SunOS
 #
-##############################################################################
+########################################################################
+#
+# Licensed to the Apache Software  Foundation (ASF) under one or more
+# contributor  license agreements.  See  the NOTICE  file distributed
+# with  this  work  for  additional information  regarding  copyright
+# ownership.   The ASF  licenses this  file to  you under  the Apache
+# License, Version  2.0 (the  "License"); you may  not use  this file
+# except in  compliance with the License.   You may obtain  a copy of
+# the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the  License is distributed on an  "AS IS" BASIS,
+# WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+# implied.   See  the License  for  the  specific language  governing
+# permissions and limitations under the License.
+#
+# Copyright 1999-2007 Rogue Wave Software, Inc.
+#
+########################################################################
 
 CXX             = CC
 
 # extract the "C++ m.n" substring from version string (whcih changes
 # from one release of the compiler to another)
 CCVER          := $(shell   $(CXX) -V 2>&1 | head -n1 \
-                          | sed 's/.*C\+\+ *\([^ ]*\).*/\1/')
+                          | sed 's/.*C++ *\([^ ]*\).*/\1/')
 CCMAJOR        := $(shell echo $(CCVER) | cut -f1 -d'.')
 CCMINOR        := $(shell echo $(CCVER) | cut -f2 -d'.')
 
@@ -28,6 +48,15 @@
 endif
 
 WARNFLAGS       = +w
+
+ifeq ($(shell expr    \( $(CCMAJOR) = 5 \& $(CCMINOR) \> 6 \) \
+                   \| $(CCMAJOR) \> 5),1)
+  # for Sun C++ 5.7 and beyond, enable diagnostic "tags" in compiler output
+  # and use -erroff to silence Warning: std::stringstream::rdbuf hides the
+  # function std::ios::rdbuf(std::streambuf*) (see STDCXX-344)
+  WARNFLAGS += -errtags -erroff=hidef
+endif
+
 PICFLAGS        = -KPIC
 LDSOFLAGS       = 
 CXXFLAGS        = -library=%none

Modified: incubator/stdcxx/branches/4.2.0/etc/config/vacpp.config
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/vacpp.config?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/vacpp.config (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/vacpp.config Fri Sep 28 13:55:52 2007
@@ -5,6 +5,26 @@
 # configuration file for IBM VisualAge and XLC++
 #
 ##############################################################################
+#
+# Licensed to the Apache Software  Foundation (ASF) under one or more
+# contributor  license agreements.  See  the NOTICE  file distributed
+# with  this  work  for  additional information  regarding  copyright
+# ownership.   The ASF  licenses this  file to  you under  the Apache
+# License, Version  2.0 (the  "License"); you may  not use  this file
+# except in  compliance with the License.   You may obtain  a copy of
+# the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the  License is distributed on an  "AS IS" BASIS,
+# WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+# implied.   See  the License  for  the  specific language  governing
+# permissions and limitations under the License.
+#
+# Copyright 1999-2007 Rogue Wave Software, Inc.
+#
+##############################################################################
 
 # see if the xlCcore command exists and use it in preference to xlC
 # xlCcore, available in VAC++ 6.0 patches released since 4/2004, and

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/build.wsf
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/build.wsf?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/build.wsf (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/build.wsf Fri Sep 28 13:55:52 2007
@@ -28,6 +28,8 @@
                 name="CONFIG" required="true" type="string"/>
             <named helpstring="Output directory for modules" 
                 name="BUILDDIR" required="true" type="string"/>
+            <named helpstring="Top directory of stdcxx sources tree" 
+                name="TOPDIR" required="false" type="string"/>
             <named helpstring="Name of the solution configuration" 
                 name="BUILDTYPE" required="true" type="string"/>
             <named helpstring="Build projects only, do not execute tests" 
@@ -35,10 +37,12 @@
             <example>cscript build.wsf /CONFIG:msvc-7.1 /BUILDTYPE:11d
             </example>
             <usage>
-Usage: cscript build.wsf /CONFIG:@CONFIG /BUILDDIR:@BUILDDIR /BUILDTYPE:@BUILDTYPE [/BUILDONLY:@BUILDONLY]
+Usage: cscript build.wsf /CONFIG:@CONFIG /BUILDDIR:@BUILDDIR
+/TOPDIR:@TOPDIR /BUILDTYPE:@BUILDTYPE [/BUILDONLY:@BUILDONLY]
 where
 @CONFIG is the compiler configuration (msvc-7.1, icc-9.0, etc).
 @BUILDDIR is the root of the build directory.
+@TOPDIR is the root of the stdcxx source tree.
 @BUILDTYPE is the build type (11d, 11s, etc).
 @BUILDONLY is one of { yes, no } - execute or not the tests.
             </usage>
@@ -61,10 +65,15 @@
 // constants
 var currentCfg = "";
 var slnDir = "";
+var srcDir = "";
 var buildType = "";
 var longConfName = "";
 var buildOnly = false;
 var outputPane = null;
+var winconfigDir = "\\etc\\config\\windows";
+var postBuildInvoked;
+var rxBuildDir = null;
+var rxTopDir = null;
 
 var description = new build; // run
 
@@ -106,8 +115,37 @@
     return log;
 }
 
+function removeLogClutter(log)
+{
+    if ("" != slnDir)
+    {
+        if (null == rxBuildDir)
+        {
+            var buildDir = slnDir.replace(/\\/g, "\\\\");
+            rxBuildDir = new RegExp("(" + buildDir + ")", "ig");
+        }
+        log = log.replace(rxBuildDir, "$(BUILDDIR)");
+    }
+
+    if ("" != srcDir)
+    {
+        if (null == rxTopDir)
+        {
+            var topDir = srcDir.replace(/\\/g, "\\\\");
+            rxTopDir = new RegExp("(" + topDir + ")", "ig");
+        }
+        log = log.replace(rxTopDir, "$(TOPDIR)");
+    }
+
+    log = log.replace(/^Build log was saved at.*$/gm, "");
+
+    return log;
+}
+
 function event_ProjectBuildFinished(Cfg, Warnings, Errors, Canceled)
 {
+    postBuildInvoked = true;
+
     var log = "";
     var htm = "BuildLog.htm";
 
@@ -132,49 +170,53 @@
         sel.SelectAll();
         log = sel.Text;
 
-        // find BuildLoh.htm path
-        var proto = "file://";
-        var begin = log.indexOf(proto);
-        if (0 <= begin)
+        var log2 = "";
+        var begin = 0;
+
+        while (true)
         {
+            // find BuildLog.htm path
+            var proto = "file://";
+            begin = log.indexOf(proto, begin);
+            if (0 > begin)
+                break;
+
             begin += proto.length;
             var end = log.indexOf(htm, begin);
-            if (0 <= end)
-            {
-                var path = log.substring(begin, end + htm.length);
-                var log2 = getBuildLog(path);
-                if (0 < log2.length)
-                    log = log2;
-            }
+            if (0 > end)
+                break;
+
+            var path = log.substring(begin, end + htm.length);
+            log2 += getBuildLog(path);
         }
+
+        if (0 < log2.length)
+            log = log2;
     }
 
-    WScript.Echo(log);
+    WScript.Echo(removeLogClutter(log));
 }
 
 function BuildProject(solutionBuild, projectName)
 {
-    var projectFile = null;
+    var projectFile = "";
     var projects = dte.Solution.Projects;
-    for (var i = 1; i <= projects.Count && null == projectFile; ++i)
+    for (var i = 1; i <= projects.Count && 0 == projectFile.length; ++i)
     {
         var project = projects.Item(i);
         if (project.Name == projectName)
             projectFile = project.UniqueName;
     }
 
-    if (null != projectFile)
+    if (0 < projectFile.length)
     {
-        var isICC = 0 < projectFile.indexOf(".icproj");
+        event_ProjectBuildStarted(null);
 
-        if (isICC)
-            // event not invoked automatically for Intel projects
-            event_ProjectBuildStarted(null);
+        postBuildInvoked = false;
 
         solutionBuild.BuildProject(longConfName, projectFile, true);
 
-        if (isICC)
-            // event not invoked automatically for Intel projects
+        if (!postBuildInvoked)
             event_ProjectBuildFinished(null, 0, 0, 0);
 
         return solutionBuild.LastBuildInfo;
@@ -197,7 +239,7 @@
     
     dte.SuppressUI = true;
     
-    var solutionName = slnDir + "\\" + currentCfg + "\\" + currentCfg + ".sln";
+    var solutionName = slnDir + "\\" + currentCfg + ".sln";
 
     WScript.Echo("Loading solution...");
     var solution = dte.Solution;
@@ -206,6 +248,9 @@
     var prop = null;
     var propVal;
     var oldLogging = null;
+    var iSettings = null;
+    var oldIccIdx = null;
+    var oldPlatIdx = null;
     var projectEngine = null;
     var events = null;
 
@@ -280,6 +325,69 @@
             prop = null;
         }
 
+        if ("" != ICCVER)
+        {
+            // select proper Intel C++ compiler
+            try
+            {
+                iSettings = dte.GetObject("IntelOptions");
+            }
+            catch (e)
+            {
+                WScript.StdErr.WriteLine(
+                    "Build: Intel C++ not installed or installed incorrectly.");
+                retCode = 1;
+                break;
+            }
+
+            oldIccIdx = iSettings.CurrentCompilerIndex;
+            oldPlatIdx = iSettings.CurrentPlatformIndex;
+            WScript.Echo("Current compiler: " +
+                         iSettings.Compiler(oldIccIdx).Name);
+
+            var ICPlatform = "IA32";
+            if ("x64" == PLATFORM)
+                ICPlatform = "EM64T";
+
+            for (var i = 0; i < iSettings.PlatformsCount; ++i)
+            {
+                iSettings.CurrentPlatformIndex = i;
+                if (ICPlatform == iSettings.CurrentPlatformName)
+                    break;
+            }
+
+            if (i >= iSettings.PlatformsCount)
+            {
+                WScript.StdErr.WriteLine(
+                    "Build: Installed ICC does not support " + PLATFORM + " platform.");
+                retCode = 1;
+                break;
+            }
+
+            var rx = new RegExp("(^.*C\\+\\+ " + ICCVER + ".*)");
+
+            for (var i = 1; i <= iSettings.CompilersCount; ++i)
+            {
+                var compname = iSettings.Compiler(i).Name;
+                if (null != rx.exec(compname))
+                    break;
+            }
+
+            if (i <= iSettings.CompilersCount)
+            {
+                iSettings.CurrentCompilerIndex = i;
+                WScript.Echo("Selected compiler: " +
+                             iSettings.Compiler(i).Name);
+            }
+            else
+            {
+                WScript.StdErr.WriteLine(
+                    "Build: ICC " + ICCVER + " not found.");
+                retCode = 1;
+                break;
+            }
+        }
+
         // save BuildLogging property value
         oldLogging = projectEngine.BuildLogging;
         projectEngine.BuildLogging = true;
@@ -346,6 +454,16 @@
     }
     while (false);
 
+    if (null != iSettings)
+    {
+        if (null != oldIccIdx)
+            iSettings.CurrentCompilerIndex = oldIccIdx;
+        if (null != oldPlatIdx)
+            iSettings.CurrentPlatformIndex = oldPlatIdx;
+
+        iSettings = null;
+    }
+
     if (null != oldLogging)
         projectEngine.BuildLogging = oldLogging;
 
@@ -400,7 +518,22 @@
     currentCfg = WScript.Arguments.Named("CONFIG");
     
     slnDir = WScript.Arguments.Named("BUILDDIR");
-    slnDir = fso.GetAbsolutePathName (slnDir);
+    slnDir = fso.GetAbsolutePathName (slnDir) + "\\" + currentCfg;
+
+    if (WScript.Arguments.Named.Exists("TOPDIR"))
+    {
+        srcDir = WScript.Arguments.Named("TOPDIR");
+    }
+    else
+    {
+        // try to deduce it
+        var myDir = WScript.ScriptFullName;
+        var dirIndex = myDir.indexOf(winconfigDir);
+        if (0 <= dirIndex)
+            srcDir = myDir.substr(0, dirIndex);
+        else
+            srcDir = "";
+    }
 
     buildType = WScript.Arguments.Named("BUILDTYPE");
     

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/configure.wsf
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/configure.wsf?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/configure.wsf (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/configure.wsf Fri Sep 28 13:55:52 2007
@@ -228,10 +228,28 @@
 
     CPPFLAGS += " /M";
 
+    LDFLAGS += " /NODEFAULTLIB:\"";
+
     if (confInfo.dll)
+    {
         CPPFLAGS += "D";
+        LDFLAGS += confInfo.debug ? "msvcprtd" : "msvcprt";
+    }
     else
-        CPPFLAGS += (confInfo.mt || NOSTCRT) ? "T" : "L";
+    {
+        if (confInfo.mt || NOSTCRT)
+        {
+            CPPFLAGS += "T";
+            LDFLAGS += confInfo.debug ? "libcpmtd" : "libcpmt";
+        }
+        else
+        {
+            CPPFLAGS += "L";
+            LDFLAGS += confInfo.debug ? "libcpd" : "libcp";
+        }
+    }
+
+    LDFLAGS += ".lib\"";
 
     if (confInfo.debug)
     {
@@ -248,10 +266,6 @@
     
     CPPFLAGS += joinArray(defines, "/D");
     
-    LDFLAGS += " /NODEFAULTLIB:libcp /NODEFAULTLIB:libcpd" +
-               " /NODEFAULTLIB:libcpmt /NODEFAULTLIB:libcpmtd" +
-               " /NODEFAULTLIB:msvcprt /NODEFAULTLIB:msvcprtd";
-
     var exitmsg = "You may see log here: " + logFileNameURI;
 
     // sanity check

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/filterdef.js
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/filterdef.js?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/filterdef.js (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/filterdef.js Fri Sep 28 13:55:52 2007
@@ -25,7 +25,7 @@
 
 var sourceFilterName = "Source Files";
 var sourceFilterUuid = "{4FC737F1-C7A5-4376-A066-2A32D752A2FF}";
-var sourceFilterExts = ".cpp;.cxx;.s";
+var sourceFilterExts = ".cpp;.cxx;.s;.asm";
 
 var headerFilterName = "Header Files";
 var headerFilterUuid = "{93995380-89BD-4b04-88EB-625FBE52EBFB}";
@@ -59,6 +59,28 @@
 // common macros
 var cmnMacros = new Array();
 
+// init custom build rule for .asm files
+function InitAsmTool(VCFile)
+{
+    var cfgs = VCFile.FileConfigurations;
+    for (var i = 1; i <= cfgs.Count; ++i)
+    {
+        var cfg = cfgs.Item(i);
+        if ((typeof(cfg.Tool.ToolKind) != "undefined" &&
+            cfg.Tool.ToolKind != "VCCustomBuildTool") ||
+            cfg.Tool.ToolName != "Custom Build Tool")
+        {
+            cfg.Tool = cfg.ProjectConfiguration.FileTools.Item("VCCustomBuildTool");
+        }
+
+        var tool = cfg.Tool;
+        tool.Description = "Compiling .asm file...";
+        tool.Outputs = "$(IntDir)\\$(InputName).obj";
+        tool.CommandLine = AS + " /c /nologo /D" + PLATFORM + " /Fo" + tool.Outputs +
+                           " /W3 /Zi /Ta" + VCFile.RelativePath;
+    }
+}
+
 //------------------------------------------------
 // FilterDef class
 //------------------------------------------------
@@ -126,7 +148,9 @@
     var VCFile = filter.AddFile(filename);
     if (null != filetype && typeof(VCFile.FileType) != "undefined")
         VCFile.FileType = filetype;
-        
+
+    var customFileDef = null;
+
     if (exclude)
     {
         var cfgs = VCFile.FileConfigurations;
@@ -144,6 +168,8 @@
             cfg.ExcludedFromBuild = exclude;
         }
     }
+    else if (".asm" == VCFile.Extension)
+        InitAsmTool(VCFile);
 }
 
 // create VCFilter object from the FilterDef definition

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/fun_present_check.cpp
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/fun_present_check.cpp?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/fun_present_check.cpp (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/fun_present_check.cpp Fri Sep 28 13:55:52 2007
@@ -1,3 +1,26 @@
+
+/***************************************************************************
+ *
+ * Licensed to the Apache Software  Foundation (ASF) under one or more
+ * contributor  license agreements.  See  the NOTICE  file distributed
+ * with  this  work  for  additional information  regarding  copyright
+ * ownership.   The ASF  licenses this  file to  you under  the Apache
+ * License, Version  2.0 (the  License); you may  not use  this file
+ * except in  compliance with the License.   You may obtain  a copy of
+ * the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the  License is distributed on an  "AS IS" BASIS,
+ * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+ * implied.   See  the License  for  the  specific language  governing
+ * permissions and limitations under the License.
+ *
+ * Copyright 1999-2007 Rogue Wave Software, Inc.
+ * 
+ **************************************************************************/
+
 extern "C"
 {
     typedef void (*funptr_t)();

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/generate.wsf
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/generate.wsf?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/generate.wsf (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/generate.wsf Fri Sep 28 13:55:52 2007
@@ -25,11 +25,11 @@
 Generates solution file for a specified environment
             </description>
             <named helpstring="Name of the compiler configuration"
-                name="CONFIG" required="true" type="string"/>
+                name="CONFIG" required="false" type="string"/>
             <named helpstring="Top directory of stdcxx sources tree" 
                 name="TOPDIR" required="false" type="string"/>
             <named helpstring="Output directory for modules" 
-                name="BUILDDIR" required="true" type="string"/>
+                name="BUILDDIR" required="false" type="string"/>
             <named helpstring="Copy dll to exe option" 
                 name="COPYDLL" required="false" type="string"/>
             <named helpstring="Generate locales projects" 
@@ -40,8 +40,8 @@
                 /BUILDDIR:"C:\stdcxx\build" /CONFIG:msvc-7.1
             </example>
             <usage>
-Usage: cscript generate.wsf /CONFIG:@CONFIG 
-/BUILDDIR:@BUILDDIR [/TOPDIR:@TOPDIR] [/COPYDLL:@COPYDLL]
+Usage: cscript generate.wsf [/CONFIG:@CONFIG]
+[/BUILDDIR:@BUILDDIR] [/TOPDIR:@TOPDIR] [/COPYDLL:@COPYDLL]
 [/LOCALES:@LOCALES] [/LOCALETESTS:@LOCALETESTS]
 where
 @CONFIG is the compiler configuration (msvc-7.1, icc-9.0, etc).
@@ -108,7 +108,7 @@
 {
     Echo("Solution generation script");
     Echo("Checking arguments...");
-    
+
     readAndCheckArguments();
     createBuildDirs();
     
@@ -116,6 +116,10 @@
     outDir += "\\" + currentCfg;
 
     Echo("Checking consistence...");
+    // get solution object
+    if (null == VCProjectEngine && !InitVSObjects(currentCfg))
+        WScript.Quit(3);
+
     logFile = currentCfg + logFile;
     logStream = fso.CreateTextFile(outDir + "\\" + logFile, true, false);
 
@@ -124,9 +128,6 @@
                     new Macro("%SRCDIR%", srcDir),
                     new Macro("%BUILDDIR%", outDir));
                         
-    // get solution object
-    InitVSObjects(currentCfg);
-
     PrintVars(logStream);
     PrintVars(WScript.StdOut);
     
@@ -228,23 +229,48 @@
 // performs checking of the script parameters
 function readAndCheckArguments()
 {
-    if (!WScript.Arguments.Named.Exists("CONFIG"))
+    if (WScript.Arguments.Named.Exists("CONFIG"))
+        currentCfg = WScript.Arguments.Named("CONFIG");
+    else
     {
-        WScript.StdErr.WriteLine(
-            "Generate: Missing required argument.");
-        WScript.Arguments.ShowUsage();
-        WScript.Quit(2);
+        // try to deduce it
+        // ICC cannot be used without VisualStudio installed
+        // so we check only for MSVC
+        Echo("CONFIG parameter not specified, trying to detect it...");
+        var cfgs = new Array("msvc-8.0", "msvc-7.1", "msvc-7.0");
+        for (var i = 0; i < cfgs.length; ++i)
+        {
+            var curCfg = cfgs[i];
+            Echo("Trying " + curCfg + "...");
+
+            if (InitVSObjects(curCfg))
+            {
+                Echo("Succeeded. Using CONFIG=" + curCfg + ".");
+                currentCfg = curCfg;
+                break;
+            }
+
+            Echo(curCfg + " checking failed.");
+        }
     }
-    
-    if (!WScript.Arguments.Named.Exists("BUILDDIR"))
+
+    if ("" == currentCfg)
     {
-        WScript.StdErr.WriteLine(
-            "Generate: Missing required argument BUILDDIR.");
-        WScript.Arguments.ShowUsage();
+        WScript.StdErr.WriteLine("No suitable config file detected.");
         WScript.Quit(2);
     }
     
-    currentCfg = WScript.Arguments.Named("CONFIG");
+    if (WScript.Arguments.Named.Exists("BUILDDIR"))
+    {
+        outDir = WScript.Arguments.Named("BUILDDIR");
+        outDir = fso.GetAbsolutePathName (outDir);
+    }
+    else
+    {
+        // use current directory
+        outDir = WshShell.CurrentDirectory;
+        Echo("BUILDDIR parameter not specified, using BUILDDIR=" + outDir);
+    }
     
     if (WScript.Arguments.Named.Exists("TOPDIR"))
     {
@@ -264,6 +290,7 @@
         }
         
         srcDir = myDir.substr(0, dirIndex);
+        Echo("TOPDIR parameter not specified, using TOPDIR=" + srcDir);
     }
    
     if (srcDir != "")
@@ -275,14 +302,6 @@
                 + srcDir);
             WScript.Quit(2);
         }
-        
-        outDir = srcDir;
-    }
-    
-    if (WScript.Arguments.Named.Exists("BUILDDIR"))
-    {
-        outDir = WScript.Arguments.Named("BUILDDIR");
-        outDir = fso.GetAbsolutePathName (outDir);
     }
     
     if (WScript.Arguments.Named.Exists("COPYDLL"))
@@ -409,8 +428,8 @@
 
         buildBatchFile.WriteLine("cscript /nologo "
             + "\"%topdir%\\%scriptdir%\\build.wsf\""
-            + " /BUILDDIR:\"%builddir%\" /BUILDTYPE:%cfgbrief%"
-            + " /CONFIG:" + currentCfg);
+            + " /BUILDDIR:\"%builddir%\" /TOPDIR:\"%topdir%\""
+            + " /BUILDTYPE:%cfgbrief% /CONFIG:" + currentCfg);
         buildBatchFile.WriteLine("cscript /nologo "
             + "\"%topdir%\\%scriptdir%\\%makelog%\""
             + " /BUILDDIR:\"%builddir%\" /BUILDTYPE:%cfgbrief%"

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/icc-9.0.config
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/icc-9.0.config?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/icc-9.0.config (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/icc-9.0.config Fri Sep 28 13:55:52 2007
@@ -1,3 +1,28 @@
+//
+// $Id$
+//
+// icc-9.0.config - configuration file for Intel C++ 9.0
+//
+//////////////////////////////////////////////////////////////////////
+//
+// Licensed to the Apache Software  Foundation (ASF) under one or more
+// contributor  license agreements.  See  the NOTICE  file distributed
+// with  this  work  for  additional information  regarding  copyright
+// ownership.   The ASF  licenses this  file to  you under  the Apache
+// License, Version  2.0 (the  "License"); you may  not use  this file
+// except in  compliance with the License.   You may obtain  a copy of
+// the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the  License is distributed on an  "AS IS" BASIS,
+// WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+// implied.   See  the License  for  the  specific language  governing
+// permissions and limitations under the License.
+// 
+//////////////////////////////////////////////////////////////////////
+
 #include msvc-7.1
 DEVENVFLAGS=/useenv
 CPPFLAGS=
@@ -7,3 +32,4 @@
 LD=icl
 AR=xilib
 CLVARSBAT=%ICPP_COMPILER90%\IA32\Bin\iclvars.bat
+ICCVER=9.0

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/icc-9.1.config
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/icc-9.1.config?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/icc-9.1.config (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/icc-9.1.config Fri Sep 28 13:55:52 2007
@@ -1,3 +1,28 @@
+//
+// $Id$
+//
+// icc-9.1.config - configuration file for Intel C++ 9.1
+//
+//////////////////////////////////////////////////////////////////////
+//
+// Licensed to the Apache Software  Foundation (ASF) under one or more
+// contributor  license agreements.  See  the NOTICE  file distributed
+// with  this  work  for  additional information  regarding  copyright
+// ownership.   The ASF  licenses this  file to  you under  the Apache
+// License, Version  2.0 (the  "License"); you may  not use  this file
+// except in  compliance with the License.   You may obtain  a copy of
+// the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the  License is distributed on an  "AS IS" BASIS,
+// WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+// implied.   See  the License  for  the  specific language  governing
+// permissions and limitations under the License.
+// 
+//////////////////////////////////////////////////////////////////////
+
 #include msvc-8.0
 DEVENVFLAGS=/useenv
 CPPFLAGS=
@@ -7,3 +32,4 @@
 LD=icl
 AR=xilib
 CLVARSBAT=%ICPP_COMPILER91%\IA32\Bin\iclvars.bat
+ICCVER=9.1

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-7.0.config
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-7.0.config?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-7.0.config (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-7.0.config Fri Sep 28 13:55:52 2007
@@ -1,7 +1,33 @@
+//
+// $Id$
+//
+// msvc-7.0.config - configuration file for Microsoft Visual C++ 7.0
+//
+//////////////////////////////////////////////////////////////////////
+//
+// Licensed to the Apache Software  Foundation (ASF) under one or more
+// contributor  license agreements.  See  the NOTICE  file distributed
+// with  this  work  for  additional information  regarding  copyright
+// ownership.   The ASF  licenses this  file to  you under  the Apache
+// License, Version  2.0 (the  "License"); you may  not use  this file
+// except in  compliance with the License.   You may obtain  a copy of
+// the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the  License is distributed on an  "AS IS" BASIS,
+// WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+// implied.   See  the License  for  the  specific language  governing
+// permissions and limitations under the License.
+// 
+//////////////////////////////////////////////////////////////////////
+
 // Version of the used MS VisualStudio:
 // 7 for MS VisualStudio .NET
 // 7.1 for MS VisualStudio .NET 2003
-// 8 for MS VisualStudio 2005 and MSVC 2005 Express Edition
+// 8.0 for MS VisualStudio 2005 and MSVC 2005 Express Edition
+// 9.0 for MS VisualStudio 2008
 VERSION=7
 
 // Path to the MS VisualStudio IDE executable:
@@ -17,8 +43,8 @@
 // if empty it will be tried to be detected automatically
 WINDIFF=
 
-// Path to the ICProjConvert90.exe utility:
-// if empty it will be tried to be detected automatically
+// Path of the ICProjConvertxx.exe utility:
+// if path is empty it will be tried to be detected automatically
 ICCCONVERT=
 
 // Convert solution to ICC format
@@ -30,14 +56,19 @@
 CPPFLAGS=
 // additional flags for the linker
 LDFLAGS=
+// additional libraries
+LIBS=
 
-// CXX, LD, AD used only at configure build step
+// CXX, LD, AR used only at configure build step
 // CXX - command invoked to compile the test source file
 // LD - command invoked to link the test
 // AR - command invoked to make library
+// AS will be used at solution generation build step
+// to initialize Custom Build Rule for compiling .asm files
 CXX=cl
 LD=cl
 AR=lib
+AS=ml
 
 // Use singlethreaded or mutlithreaded CRT in 11s, 11d solution configurations
 // 0 for MS VisualStudio .NET and MS VisualStudio .NET 2003
@@ -54,12 +85,14 @@
 // 7.00 for MS VisualStudio .NET
 // 8.00 for MS VisualStudio .NET 2003
 // 9.00 for MS VisualStudio 2005 and MSVC 2005 Express Edition
+// 10.00 for MS VisualStudio 2008
 SLNVER=7.00
 
 // Comment in produced solution file:
 // empty for MS VisualStudio .NET and MS VisualStudio .NET 2003
 // Visual Studio 2005 - for MS VisualStudio 2005
 // Visual C++ Express 2005 - for MSVC 2005 Express Edition
+// Visual Studio 2008 - for MS VisualStudio 2008
 SLNCOMMENT=
 
 // Type of produced file buildlog.htm:
@@ -70,3 +103,7 @@
 // Path to the ICC iclvars.bat
 // Should be empty for MSVC
 CLVARSBAT=
+
+// Version of the Intel C++
+// Should be empty for MSVC
+ICCVER=

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-7.1.config
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-7.1.config?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-7.1.config (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-7.1.config Fri Sep 28 13:55:52 2007
@@ -1,3 +1,28 @@
+//
+// $Id$
+//
+// msvc-7.1.config - configuration file for Microsoft Visual C++ 7.1
+//
+//////////////////////////////////////////////////////////////////////
+//
+// Licensed to the Apache Software  Foundation (ASF) under one or more
+// contributor  license agreements.  See  the NOTICE  file distributed
+// with  this  work  for  additional information  regarding  copyright
+// ownership.   The ASF  licenses this  file to  you under  the Apache
+// License, Version  2.0 (the  "License"); you may  not use  this file
+// except in  compliance with the License.   You may obtain  a copy of
+// the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the  License is distributed on an  "AS IS" BASIS,
+// WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+// implied.   See  the License  for  the  specific language  governing
+// permissions and limitations under the License.
+// 
+//////////////////////////////////////////////////////////////////////
+
 #include msvc-7.0
 VERSION=7.1
 CPPFLAGS=

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-8.0-x64.config
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-8.0-x64.config?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-8.0-x64.config (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-8.0-x64.config Fri Sep 28 13:55:52 2007
@@ -1,2 +1,29 @@
+//
+// $Id$
+//
+// msvc-8.0-x64.config - configuration file for
+//                       64 bit Microsoft Visual C++ 8.0
+//
+//////////////////////////////////////////////////////////////////////
+//
+// Licensed to the Apache Software  Foundation (ASF) under one or more
+// contributor  license agreements.  See  the NOTICE  file distributed
+// with  this  work  for  additional information  regarding  copyright
+// ownership.   The ASF  licenses this  file to  you under  the Apache
+// License, Version  2.0 (the  "License"); you may  not use  this file
+// except in  compliance with the License.   You may obtain  a copy of
+// the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the  License is distributed on an  "AS IS" BASIS,
+// WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+// implied.   See  the License  for  the  specific language  governing
+// permissions and limitations under the License.
+// 
+//////////////////////////////////////////////////////////////////////
+
 #include msvc-8.0
 PLATFORM=x64
+AS=ml64

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-8.0.config
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-8.0.config?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-8.0.config (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/msvc-8.0.config Fri Sep 28 13:55:52 2007
@@ -1,3 +1,28 @@
+//
+// $Id$
+//
+// msvc-8.0.config - configuration file for Microsoft Visual C++ 8.0
+//
+//////////////////////////////////////////////////////////////////////
+//
+// Licensed to the Apache Software  Foundation (ASF) under one or more
+// contributor  license agreements.  See  the NOTICE  file distributed
+// with  this  work  for  additional information  regarding  copyright
+// ownership.   The ASF  licenses this  file to  you under  the Apache
+// License, Version  2.0 (the  "License"); you may  not use  this file
+// except in  compliance with the License.   You may obtain  a copy of
+// the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the  License is distributed on an  "AS IS" BASIS,
+// WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+// implied.   See  the License  for  the  specific language  governing
+// permissions and limitations under the License.
+// 
+//////////////////////////////////////////////////////////////////////
+
 #include msvc-7.0
 VERSION=8.0
 CPPFLAGS=/D_CRT_SECURE_NO_DEPRECATE

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/msvcex-8.0.config
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/msvcex-8.0.config?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/msvcex-8.0.config (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/msvcex-8.0.config Fri Sep 28 13:55:52 2007
@@ -1,3 +1,30 @@
+//
+// $Id$
+//
+// msvcex-8.0.config - configuration file for
+//                     Microsoft Visual C++ 8.0 Express Edition
+//
+//////////////////////////////////////////////////////////////////////
+//
+// Licensed to the Apache Software  Foundation (ASF) under one or more
+// contributor  license agreements.  See  the NOTICE  file distributed
+// with  this  work  for  additional information  regarding  copyright
+// ownership.   The ASF  licenses this  file to  you under  the Apache
+// License, Version  2.0 (the  "License"); you may  not use  this file
+// except in  compliance with the License.   You may obtain  a copy of
+// the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the  License is distributed on an  "AS IS" BASIS,
+// WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+// implied.   See  the License  for  the  specific language  governing
+// permissions and limitations under the License.
+// 
+//////////////////////////////////////////////////////////////////////
+
 #include msvc-8.0
 DEVENV=VCExpress.exe
 SLNCOMMENT=Visual C++ Express 2005
+LIBS=user32.lib

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/projectdef.js
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/projectdef.js?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/projectdef.js (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/projectdef.js Fri Sep 28 13:55:52 2007
@@ -27,9 +27,6 @@
 var TristateTrue = -1;
 var TristateFalse = 0;
 
-// the timeout for the exec utility
-var execTimeout = 180;
-
 var dte = null;
 var VCProjectEngine = null;
 var ICConvertTool = "ICProjConvert90.exe";
@@ -69,24 +66,28 @@
 
     if (CONVERT)
     {
+        if (ICCCONVERT == "")
+            ICCCONVERT = "ICProjConvert90.exe";
+
         var ICConvertTool = ICCCONVERT;
 
         var arrPath = new Array(ICConvertTool);
 
-        if (ICConvertTool == "")
+        if (0 > ICConvertTool.indexOf("\\"))
         {
-            ICConvertTool = "ICProjConvert90.exe";
-            arrPath[0] = ICConvertTool;
+            // no file path specified
+            // try to detect the path
             if (null != dte)
             {
                 try
                 {
                     var isettings = dte.GetObject("IntelOptions");
-                    var icompiler = isettings.Compiler(isettings.CurrentCompilerIndex);
-                    var path = icompiler.ExecutablePath.split(";");
-                    for (var i = 0; i < path.length; ++i)
-                        arrPath.push("\"" + path[i] + "\\" + ICConvertTool + "\"");
-                    icompiler = null;
+                    for (var i = 1; i <= isettings.CompilersCount; ++i)
+                    {
+                        var paths = isettings.Compiler(i).ExecutablePath.split(";");
+                        for (var j = 0; j < paths.length; ++j)
+                            arrPath.push("\"" + isettings.Evaluate(paths[j]) + "\\" + ICConvertTool + "\"");
+                    }
                     isettings = null;
                 }
                 catch (e) {}
@@ -106,6 +107,7 @@
         if (!success)
         {
             WScript.StdErr.WriteLine(ICCCONVERT + " conversion utility not found");
+            WScript.StdErr.WriteLine("You should check ICCCONVERT configuration variable");
             WScript.Quit(3);
         }
     }
@@ -123,8 +125,10 @@
     catch (e)
     {
         WScript.StdErr.WriteLine("Unable to create VCProjectEngine object: " + e.message);
-        WScript.Quit(3);
+        return false;
     }
+
+    return true;
 }
 
 //------------------------------------------------
@@ -138,7 +142,7 @@
     this.Type = type;
     this.SubSystem = typeGeneric == type ? null :
         (typeApplication == type ? subSystemConsole : subSystemWindows);
-    this.RTTI = false;
+    this.RTTI = true;
     this.VCProjDir = "%BUILDDIR%";
     this.FilterDefs = new Array();
     this.Defines = null;
@@ -441,7 +445,7 @@
                     if (!setProperty(compiler.OptimizeForWindowsApplication, true))
                         compiler.AdditionalOptions += " /GA";
                 }
-                compiler.Optimization = optimizeMinSpace;
+                compiler.Optimization = optimizeMaxSpeed;
                 compiler.MinimalRebuild = false;
                 setProperty(compiler.SmallerTypeCheck, false);
                 setProperty(compiler.BasicRuntimeChecks, runtimeBasicCheckNone);
@@ -487,9 +491,22 @@
             linker.GenerateDebugInformation = true;
             if (null != this.Libs)
                 linker.AdditionalDependencies = this.Libs;
-            linker.IgnoreDefaultLibraryNames = "libcp.lib;libcpd.lib;" +
-                                               "libcpmt.lib;libcpmtd.lib;" +
-                                               "msvcprt.lib;msvcprtd.lib";
+
+            if (confInfo.dll)
+            {
+                linker.IgnoreDefaultLibraryNames =
+                    confInfo.debug ? "msvcprtd.lib" : "msvcprt.lib";
+            }
+            else
+            {
+                if (confInfo.mt || NOSTCRT)
+                    linker.IgnoreDefaultLibraryNames =
+                        confInfo.debug ? "libcpmtd.lib" : "libcpmt.lib";
+                else
+                    linker.IgnoreDefaultLibraryNames =
+                        confInfo.debug ? "libcpd.lib" : "libcp.lib";
+            }
+
             linker.SubSystem = this.SubSystem;
             if (confInfo.debug)
             {
@@ -793,7 +810,7 @@
     sanityDef.PreBuildCmd +=
         "echo cscript /nologo \"" + srcdir + "\\run_locale_utils.wsf\"" +
         " /s /b:\"" + bindir + "\" > \"" + test + ".bat\"";
-    sanityDef.CustomBuildCmd = setPath + "\r\n\"" + exec + "\" -t " + execTimeout + " \"" + test + ".bat\"";
+    sanityDef.CustomBuildCmd = setPath + "\r\n\"" + exec + "\" -t " + EXEC_TIMEOUT + " \"" + test + ".bat\"";
     sanityDef.CustomBuildOut = test + ".out";
     projectDefs.push(sanityDef);
         
@@ -846,7 +863,7 @@
             "echo cscript /nologo \"" + srcdir + "\\run_locale_utils.wsf\"" +
             " /f /b:\"" + bindir + "\" /i:\"" + nlsDir + "\"" +
             " /l:" + locale.Name + " > \"" + test + ".bat\"";
-        projectDef.CustomBuildCmd = setPath + "\r\n\"" + exec + "\" -t " + execTimeout + " \"" + test + ".bat\"";
+        projectDef.CustomBuildCmd = setPath + "\r\n\"" + exec + "\" -t " + EXEC_TIMEOUT + " \"" + test + ".bat\"";
         projectDef.CustomBuildOut = test + ".out";
         projectDef.PrjDeps.push(sanityDef);
         

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/projects.js
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/projects.js?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/runall.wsf (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/runall.wsf Fri Sep 28 13:55:52 2007
@@ -34,10 +34,10 @@
                 name="INOUTDIR" required="false" type="string"/>
             <named helpstring="The log file" name="LOGFILE" 
                 required="false" type="string"/>
-            <named helpstring="Run tests in compat mode" name="COMPAT" 
-                required="false" type="string"/>
             <named helpstring="The examples extension" name="EXT" 
                 required="false" type="string"/>
+            <named helpstring="The additional options for exec utility"
+                name="RUNFLAGS" required="false" type="string"/>
             <example>
             cscript runall.wsf /EXEDIR:"C:\stdcxx\build\examples" 
             /PRJDIR:"C:\stdcxx\build\projects\examples"
@@ -46,7 +46,7 @@
             <usage>
 Usage: cscript runexamples.wsf /EXEDIR:@EXEDIR /CONFIG:@CONFIG
 [/PRJDIR:@PRJDIR] [/INOUTDIR:@INOUTDIR] [/LOGFILE:@LOGFILE]
-[/COMPAT] [/EXT:@EXT]
+[/EXT:@EXT] [/RUNFLAGS:@RUNFLAGS]
 where
 @EXEDIR is the root directory with executables to be run and checked,
 @PRJDIR is the directory with .vcproj files of the executables,
@@ -54,8 +54,8 @@
 required by executables,
 @CONFIG is the compiler configuration (msvc-7.1, icc-9.0, etc),
 @LOGFILE is the log file name,
-@COMPAT is the option for run tests in compat mode,
 @EXT is the extension of the example files, default value: "exe".
+@RUNFLAGS is the additional options for exec utility
             </usage>
         </runtime>
         <object id="fso" progid="Scripting.FileSystemObject"/>
@@ -76,8 +76,8 @@
 var currentCfg = "msvc-7.1" // the configuration
 var logFileName = ""; // the log file name
 var logFileDefault = "runexamples.log"; // the default log file name
-var compatMode = false;
 var ext = "exe";
+var runflags = "";
 
 var varOut = "out";
 
@@ -88,8 +88,6 @@
 var exBadCode = 0;
 var exNotCompiled = 0;
 
-var runTimeout = 180;
-
 var buildlogFile = "BuildLog.htm";
 var summaryFileName = "Summary.htm";
 var htmFolderName = "temphtm";
@@ -165,12 +163,15 @@
     else
         logFileName = logFileDefault;
         
-    if (WScript.Arguments.Named.Exists("COMPAT"))
-        compatMode = true;
-    
     if (WScript.Arguments.Named.Exists("EXT"))
         ext = WScript.Arguments.Named("EXT");
     
+    if (WScript.Arguments.Named.Exists("RUNFLAGS"))
+    {
+        runflags = WScript.Arguments.Named("RUNFLAGS");
+        runflags = runflags.replace(/\'/g, "\"");
+    }
+
     if (! fso.FolderExists(examplesDir))
     {
         WScript.StdErr.WriteLine(
@@ -242,36 +243,65 @@
         ++exRun;
     }
     
-    var runCmd = "\"" + utlExec + "\" -t " + runTimeout;
+    var runCmd = utlExec;
     
     if (0 < srcDir.length)
         runCmd += " -d \"" + srcDir + "\"";
 
-    if (compatMode)
-        runCmd += " --compat -x \"--compat -O -\"";
-        
-    runCmd += " " + exeFiles.join(" ");
+    if (0 < runflags.length)
+        runCmd += " " + runflags + " ";
 
+    var targets = exeFiles.join(" ");
+    var target_list = null;
+    
     var prevDir = WshShell.CurrentDirectory;
     WshShell.CurrentDirectory = exeDir;
-    var oExec = WshShell.Exec(runCmd);
-    WshShell.CurrentDirectory = prevDir;
     
-    if (!oExec)
+    // the max command line len == 2047 for Win2000
+    // http://support.microsoft.com/kb/830473
+    var MaxCmdLineLen = 2047;
+    if (MaxCmdLineLen >= runCmd.length + targets.length)
+        runCmd += exeFiles.join(" ");
+    else
     {
-        // WScript.Echo(itemInfo.name + " failed to run");
-        return;
+        target_list = "targets.lst";
+        
+        var strm = fso.CreateTextFile(target_list, true);
+        for (var i = 0; i < exeFiles.length; ++i)
+            strm.WriteLine(exeFiles[i]);
+        strm.Close();
+        
+        runCmd += "@" + target_list;
     }
 
-    var execOut = "";
-    while (oExec.Status == 0)
+    try
     {
+        runCmd = "cmd /c " + runCmd + " 2>&1";
+        var oExec = WshShell.Exec(runCmd);
+
+        var execOut = "";
+        while (oExec.Status == 0)
+        {
+            execOut += oExec.StdOut.ReadAll();
+            WScript.Sleep(100);
+        }
+
         execOut += oExec.StdOut.ReadAll();
-        WScript.Sleep(500);
+        WScript.Echo(execOut);
     }
-    
-    WScript.Echo(execOut);
-    
+    catch (e)
+    {
+        WScript.Echo("Exception in WshShell.Exec(" + runCmd + "): " + e.message);
+        return;
+    }
+    finally
+    {
+        if (null != target_list)
+            fso.DeleteFile(target_list);
+
+        WshShell.CurrentDirectory = prevDir;
+    }
+
     for (var i = 0; i < arrInfo.length; ++i)
     {
         var itemInfo = arrInfo[i];
@@ -300,12 +330,15 @@
         {
         case  0: // OK
         case -7: // OUTPUT
+        case -8: // FORMAT
+        case -9: // NOUT
             ++exRunSucceeded;
             fileLog.WriteLine(itemInfo.name + " completed successfully, exit code " +
                 itemInfo.exitCode);
             break;
-        case -1: // other
-        case -4: // SEGV
+        case -1:  // other
+        case -4:  // SEGV
+        case -10: // TRAP
             ++exRunFailed;
             fileLog.WriteLine(itemInfo.name + " failed");
             break;
@@ -371,6 +404,15 @@
                 break;
             case "OUTPUT":
                 res = -7;
+                break;
+            case "FORMAT":
+                res = -8;
+                break;
+            case "  NOUT":
+                res = -9;
+                break;
+            case "  TRAP":
+                res = -10;
                 break;
             default:
                 res = -1;

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/utilities.js
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/utilities.js?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/utilities.js (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/utilities.js Fri Sep 28 13:55:52 2007
@@ -23,23 +23,59 @@
 // 
 //////////////////////////////////////////////////////////////////////
 
-var VERSION = "7.1";
+var VERSION = "";
 var DEVENV = "";
 var DEVENVFLAGS = "";
 var CPPFLAGS = "";
 var LDFLAGS = "";
+var LIBS = "";
 var CONVERT = false;
-var CXX = "cl";
-var LD = "cl";
-var AR = "lib";
-var SLNVER="8.00";
+var CXX = "";
+var LD = "";
+var AR = "";
+var AS = "";
+var SLNVER="";
 var SLNCOMMENT="";
 var UNICODELOG = false;
 var NOSTCRT = false;
 var WINDIFF = "";
 var ICCCONVERT = "";
-var PLATFORM = "Win32";
+var PLATFORM = "";
 var CLVARSBAT = "";
+var ICCVER="";
+
+// timeout for exec utility in seconds
+var EXEC_TIMEOUT = 300;
+
+// expand system macros
+function expandSysMacro(str)
+{
+    var env = null;
+    var pos = 0;
+
+    while (true)
+    {
+        pos = str.indexOf("%", pos);
+        if (0 > pos)
+            break;
+
+        ++pos;
+        var pos2 = str.indexOf("%", pos);
+        if (0 > pos2)
+            break;
+
+        if (null == env)
+            env = WshShell.Environment("PROCESS");
+
+        var macro = str.substring(pos, pos2);
+        pos = pos2 + 1;
+        var value = env.Item(macro);
+        if ("undefined" != typeof(value) && "" != value)
+            str = str.replace("%" + macro + "%", value);
+    }
+
+    return str;
+}
 
 // read and parse compiler configuration file
 // config - name of the compiler configuration
@@ -80,6 +116,8 @@
         if (null == arr || 0 == arr[2].length)
             continue;
 
+        arr[2] = expandSysMacro(arr[2]);
+
         switch (arr[1])
         {
         case "VERSION":
@@ -97,6 +135,9 @@
         case "LDFLAGS":
             LDFLAGS = arr[2];
             break;
+        case "LIBS":
+            LIBS = arr[2];
+            break;
         case "CONVERT":
             CONVERT = parseInt(arr[2]) != 0;
             break;
@@ -109,6 +150,9 @@
         case "AR":
             AR = arr[2];
             break;
+        case "AS":
+            AS = arr[2];
+            break;
         case "SLNVER":
             SLNVER = arr[2];
             break;
@@ -133,6 +177,9 @@
         case "CLVARSBAT":
             CLVARSBAT = arr[2];
             break;
+        case "ICCVER":
+            ICCVER = arr[2];
+            break;
         }
     }
 }
@@ -140,6 +187,28 @@
 // init script variables for specified compiler configuration
 function getCompilerOpts(config)
 {
+    // set vars to initial state
+    VERSION = "";
+    DEVENV = "";
+    DEVENVFLAGS = "";
+    CPPFLAGS = "";
+    LDFLAGS = "";
+    LIBS = "";
+    CONVERT = false;
+    CXX = "";
+    LD = "";
+    AR = "";
+    AS = "";
+    SLNVER="";
+    SLNCOMMENT="";
+    UNICODELOG = false;
+    NOSTCRT = false;
+    WINDIFF = "";
+    ICCCONVERT = "";
+    PLATFORM = "";
+    CLVARSBAT = "";
+    ICCVER = "";
+
     parseConfig(config);
 
     if (0 == WINDIFF.length)
@@ -172,10 +241,12 @@
     stream.WriteLine("  DEVENVFLAGS=" + DEVENVFLAGS);
     stream.WriteLine("  CPPFLAGS=" + CPPFLAGS);
     stream.WriteLine("  LDFLAGS=" + LDFLAGS);
+    stream.WriteLine("  LIBS=" + LIBS);
     stream.WriteLine("  CONVERT=" + CONVERT);
     stream.WriteLine("  CXX=" + CXX);
     stream.WriteLine("  LD=" + LD);
     stream.WriteLine("  AR=" + AR);
+    stream.WriteLine("  AS=" + AS);
     stream.WriteLine("  SLNVER=" + SLNVER);
     stream.WriteLine("  SLNCOMMENT=" + SLNCOMMENT);
     stream.WriteLine("  UNICODELOG=" + UNICODELOG);
@@ -184,6 +255,7 @@
     stream.WriteLine("  ICCCONVERT=" + ICCCONVERT);
     stream.WriteLine("  PLATFORM=" + PLATFORM);
     stream.WriteLine("  CLVARSBAT=" + CLVARSBAT);
+    stream.WriteLine("  ICCVER=" + ICCVER);
     stream.WriteLine("");
 }
 

Modified: incubator/stdcxx/branches/4.2.0/etc/config/xlC_version.sh
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/xlC_version.sh?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/config/xlC_version.sh (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/xlC_version.sh Fri Sep 28 13:55:52 2007
@@ -4,6 +4,28 @@
 #
 # prints IBM VisualAge and XLC/C++ version
 #
+##############################################################################
+#
+# Licensed to the Apache Software  Foundation (ASF) under one or more
+# contributor  license agreements.  See  the NOTICE  file distributed
+# with  this  work  for  additional information  regarding  copyright
+# ownership.   The ASF  licenses this  file to  you under  the Apache
+# License, Version  2.0 (the  "License"); you may  not use  this file
+# except in  compliance with the License.   You may obtain  a copy of
+# the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the  License is distributed on an  "AS IS" BASIS,
+# WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+# implied.   See  the License  for  the  specific language  governing
+# permissions and limitations under the License.
+#
+# Copyright 1999-2007 Rogue Wave Software, Inc.
+#
+##############################################################################
+#
 # reported versions and patches they correspond to:
 #
 # version    release/patch

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ANSI_X3.110-1983
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ANSI_X3.110-1983?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ANSI_X3.110-1983 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ANSI_X3.110-1983 Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> ANSI_X3.110-1983
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % version: 1.0
 % repertoiremap: mnemonic,ds
 %  source: ECMA registry

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ANSI_X3.4-1968
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ANSI_X3.4-1968?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ANSI_X3.4-1968 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ANSI_X3.4-1968 Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> ANSI_X3.4-1968
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % version: 1.0
 % repertoiremap: mnemonic,ds
 %  source: ECMA registry

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ASMO_449
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ASMO_449?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ASMO_449 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/ASMO_449 Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> ASMO_449
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % version: 1.0
 %  source: ECMA registry
 

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BIG5
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BIG5?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BIG5 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BIG5 Fri Sep 28 13:55:52 2007
@@ -3,7 +3,27 @@
 <mb_cur_min>  1
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % Chinese charmap for BIG5 (CP950)
 % version: 0.92
 % Contact: Tung-Han Hsieh   <th...@linux.org.tw>

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BIG5-HKSCS
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BIG5-HKSCS?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BIG5-HKSCS (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BIG5-HKSCS Fri Sep 28 13:55:52 2007
@@ -3,7 +3,27 @@
 <mb_cur_min>  1
 <comment_char> %
 <escape_char> /
-
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % alias BIG5HKSCS
 
 %

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BS_4730
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BS_4730?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BS_4730 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BS_4730 Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> BS_4730
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % version: 1.0
 % repertoiremap: mnemonic,ds
 %  source: ECMA registry

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BS_VIEWDATA
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BS_VIEWDATA?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BS_VIEWDATA (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/BS_VIEWDATA Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> BS_VIEWDATA
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % version: 1.0
 % repertoiremap: mnemonic,ds
 %  source: ECMA registry

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP10007
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP10007?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP10007 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP10007 Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> CP10007
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 % This is the old MacCyrillic which M$ keeps around as CP10007.
 CHARMAP

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1250
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1250?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1250 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1250 Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> CP1250
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % version: 1.0
 % repertoiremap: mnemonic,ds
 %  source: UNICODE 1.0

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1251
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1251?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1251 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1251 Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> CP1251
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % version: 1.0
 % repertoiremap: mnemonic,ds
 %  source: UNICODE 1.0

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1252
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1252?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1252 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1252 Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> CP1252
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % version: 1.0
 % repertoiremap: mnemonic,ds
 %  source: UNICODE 1.0

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1253
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1253?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1253 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1253 Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> CP1253
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % version: 1.0
 % repertoiremap: mnemonic,ds
 %  source: UNICODE 1.0

Modified: incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1254
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1254?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================
--- incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1254 (original)
+++ incubator/stdcxx/branches/4.2.0/etc/nls/charmaps/CP1254 Fri Sep 28 13:55:52 2007
@@ -1,6 +1,27 @@
 <code_set_name> CP1254
 <comment_char> %
 <escape_char> /
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+% Licensed to the Apache Software  Foundation (ASF) under one or more
+% contributor  license agreements.  See  the NOTICE  file distributed
+% with  this  work  for  additional information  regarding  copyright
+% ownership.   The ASF  licenses this  file to  you under  the Apache
+% License, Version  2.0 (the  License); you may  not use  this file  
+% except in  compliance with the License.   You may obtain  a copy of
+% the License at
+%
+% http://www.apache.org/licenses/LICENSE-2.0
+%
+% Unless required by applicable law or agreed to in writing, software
+% distributed under the  License is distributed on an  "AS IS" BASIS,
+% WITHOUT  WARRANTIES OR CONDITIONS  OF ANY  KIND, either  express or
+% implied.   See  the License  for  the  specific language  governing
+% permissions and limitations under the License.
+%
+% Copyright 1999-2007 Rogue Wave Software, Inc.
+%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % version: 1.0
 % repertoiremap: mnemonic,ds
 %  source: UNICODE 1.0
--- incubator/stdcxx/branches/4.2.0/etc/config/windows/projects.js (original)
+++ incubator/stdcxx/branches/4.2.0/etc/config/windows/projects.js Fri Sep 28 13:55:52 2007
@@ -27,7 +27,6 @@
 var commonIncludes = "$(SolutionDir)%CONFIG%\\include";
 var stdcxxIncludes = "%SRCDIR%\\include;%SRCDIR%\\include\\ansi;" + commonIncludes;
 var rwtestIncludes = "%SRCDIR%\\tests\\include;" + stdcxxIncludes;
-var commonLibs = "kernel32.lib user32.lib";
 
 var binPath = "$(SolutionDir)%CONFIG%\\bin";
 var libPath = "$(SolutionDir)%CONFIG%\\lib";
@@ -35,7 +34,7 @@
 var ProjectsDir = "%BUILDDIR%\\Projects";
 
 // projects which requires RTTI support
-var RTTIProjects = new Array("18.exception");
+var NonRTTIProjects = new Array();
 
 var rxExcludedFolders = 
     new RegExp("^(?:\\.svn|Release.*|Debug.*|in|out|CVS)$","i");
@@ -67,7 +66,8 @@
     configureDef.IntDir = configureDef.OutDir;
     configureDef.CustomBuildFile = "configure.wsf";
     if (0 < CLVARSBAT.length)
-        configureDef.CustomBuildCmd = "call \"" + CLVARSBAT + "\"\r\n";
+        configureDef.CustomBuildCmd = "echo Calling \"" + CLVARSBAT + "\"\r\n" +
+                                      "call \"" + CLVARSBAT + "\"\r\n";
     else
         configureDef.CustomBuildCmd = "";
     configureDef.CustomBuildCmd += "cscript /nologo \"%CUSTOMFILE%\"" +
@@ -86,9 +86,8 @@
 ///////////////////////////////////////////////////////////////////////////////
     var stdcxxDef = new ProjectDef(".stdcxx", typeLibrary);
     stdcxxDef.VCProjDir = ProjectsDir;
-    stdcxxDef.RTTI = true;
     stdcxxDef.FilterDefs.push(
-        new FilterDef(sourceFilterName, sourceFilterUuid, sourceFilterExts, eFileTypeCppCode, false).
+        new FilterDef(sourceFilterName, sourceFilterUuid, sourceFilterExts + ";.inc", eFileTypeCppCode, false).
             addFilesByMask("%SRCDIR%\\src", rxExcludedFolders, null));
     stdcxxDef.FilterDefs.push(
         new FilterDef(headerFilterName, headerFilterUuid, headerFilterExts, eFileTypeCppHeader, true).
@@ -99,7 +98,7 @@
     stdcxxDef.Includes = stdcxxIncludes;
     stdcxxDef.OutDir = libPath;
     stdcxxDef.IntDir = "$(SolutionDir)%CONFIG%\\src";
-    stdcxxDef.Libs = commonLibs;
+    stdcxxDef.Libs = LIBS;
     stdcxxDef.OutFile = "$(OutDir)\\libstd%CONFIG%%EXT%";
     stdcxxDef.PrjDeps.push(configureDef);
 
@@ -120,7 +119,7 @@
     rwtestDef.Includes = rwtestIncludes;
     rwtestDef.OutDir = "$(SolutionDir)%CONFIG%\\tests";
     rwtestDef.IntDir = rwtestDef.OutDir + "\\src";
-    rwtestDef.Libs = commonLibs;
+    rwtestDef.Libs = LIBS;
     rwtestDef.PrjRefs.push(stdcxxDef);
 
     projectDefs.push(new Array(rwtestDef));
@@ -141,7 +140,7 @@
     execDef.Defines = "";
     execDef.Includes = commonIncludes;
     execDef.OutDir = binPath;
-    execDef.Libs = commonLibs;
+    execDef.Libs = LIBS;
     execDef.OutFile = "$(OutDir)\\exec.exe";
     execDef.PrjDeps.push(configureDef);
 
@@ -168,7 +167,7 @@
     localedefDef.Defines = commonDefines;
     localedefDef.Includes = stdcxxIncludes;
     localedefDef.OutDir = binPath;
-    localedefDef.Libs = commonLibs;
+    localedefDef.Libs = LIBS;
     localedefDef.OutFile = "$(OutDir)\\localedef.exe";
     localedefDef.PrjRefs.push(stdcxxDef);
 
@@ -184,13 +183,29 @@
     localeDef.Defines = commonDefines;
     localeDef.Includes = stdcxxIncludes;
     localeDef.OutDir = binPath;
-    localeDef.Libs = commonLibs;
+    localeDef.Libs = LIBS;
     localeDef.OutFile = "$(OutDir)\\locale.exe";
     localeDef.PrjDeps.push(configureDef);
 
     utilsArray.push(localeDef);
 
 ///////////////////////////////////////////////////////////////////////////////
+    var gencatDef = new ProjectDef("util_gencat", typeApplication);
+    gencatDef.VCProjDir = ProjectsDir + "\\util";
+    gencatDef.FilterDefs.push(
+        new FilterDef(sourceFilterName, sourceFilterUuid, sourceFilterExts, eFileTypeCppCode, false).
+            addFiles("%SRCDIR%\\util",
+                new Array("gencat.cpp")));
+    gencatDef.Defines = commonDefines;
+    gencatDef.Includes = stdcxxIncludes;
+    gencatDef.OutDir = binPath;
+    gencatDef.Libs = LIBS;
+    gencatDef.OutFile = "$(OutDir)\\gencat.exe";
+    gencatDef.PrjRefs.push(stdcxxDef);
+
+    utilsArray.push(gencatDef);
+
+///////////////////////////////////////////////////////////////////////////////
     var utilsDef = new ProjectDef(".stdcxx_utils", typeGeneric);
     utilsDef.VCProjDir = ProjectsDir + "\\util";
     utilsDef.OutDir = binPath;
@@ -198,6 +213,7 @@
     utilsDef.PrjDeps.push(execDef);
     utilsDef.PrjDeps.push(localedefDef);
     utilsDef.PrjDeps.push(localeDef);
+    utilsDef.PrjDeps.push(gencatDef);
 
     utilsArray.push(utilsDef);
 
@@ -211,7 +227,7 @@
     exampleTplDef.Defines = commonDefines;
     exampleTplDef.Includes = "%SRCDIR%\\examples\\include;" + stdcxxIncludes;
     exampleTplDef.OutDir = "$(SolutionDir)%CONFIG%\\examples";
-    exampleTplDef.Libs = commonLibs;
+    exampleTplDef.Libs = LIBS;
     exampleTplDef.PrjRefs.push(stdcxxDef);
     
     var exampleDefs = exampleTplDef.createProjectDefsFromFolder(
@@ -256,7 +272,8 @@
         " /EXEDIR:\"$(OutDir)\"" +
         " /PRJDIR:\"" + runexamplesDef.VCProjDir + "\"" +
         " /CONFIG:\"%SOLUTION%\"" +
-        " /LOGFILE:\"runexamples.log\"";
+        " /LOGFILE:\"runexamples.log\"" +
+        " /RUNFLAGS:\"-t " + EXEC_TIMEOUT + "\"";
     runexamplesDef.CustomBuildOut = "$(OutDir)\\runexamples.log";
     runexamplesDef.CustomBuildDeps = "%FILES%";
     //runexamplesDef.PrjDeps.push(allexamplesDef);
@@ -269,11 +286,10 @@
 
     var testTplDef = new ProjectDef(null, typeApplication);
     testTplDef.VCProjDir = ProjectsDir + "\\tests";
-    testTplDef.RTTI = true;
     testTplDef.Defines = commonDefines;
     testTplDef.Includes = rwtestIncludes;
     testTplDef.OutDir = "$(SolutionDir)%CONFIG%\\tests";
-    testTplDef.Libs = commonLibs;
+    testTplDef.Libs = LIBS;
     testTplDef.PrjRefs.push(stdcxxDef);
     testTplDef.PrjRefs.push(rwtestDef);
     
@@ -312,16 +328,18 @@
     runtestsDef.CustomBuildFile = "runall.wsf";
     runtestsDef.CustomBuildCmd =
         "set PATH=$(SolutionDir)%CONFIG%\\bin;$(SolutionDir)%CONFIG%\\lib;%PATH%\r\n" +
+        "set TOPDIR=%SRCDIR%\r\n" +
+        "set BINDIR=$(SolutionDir)%CONFIG%\\bin\r\n" +
         "cscript /nologo \"%CUSTOMFILE%\"" +
         " /EXEDIR:\"$(OutDir)\"" +
         " /PRJDIR:\"" + runtestsDef.VCProjDir + "\"" +
         " /CONFIG:\"%SOLUTION%\"" +
-        " /COMPAT" +
-        " /LOGFILE:\"runtests.log\"";
+        " /LOGFILE:\"runtests.log\"" +
+        " /RUNFLAGS:\"--compat -x \'--compat -O -\' -t " + EXEC_TIMEOUT + "\"";
     runtestsDef.CustomBuildOut = "$(OutDir)\\runtests.log";
     runtestsDef.CustomBuildDeps = "%FILES%";
     //runtestsDef.PrjDeps.push(alltestsDef);
-    runtestsDef.PrjDeps.push(execDef);
+    runtestsDef.PrjDeps.push(utilsDef);
 
     projectDefs.push(new Array(runtestsDef));
 
@@ -394,7 +412,8 @@
         " /EXEDIR:\"$(OutDir)\"" +
         " /CONFIG:\"%SOLUTION%\"" +
         " /LOGFILE:\"runloctests.log\"" +
-        " /EXT:bat";
+        " /EXT:bat" +
+        " /RUNFLAGS:\"-t " + EXEC_TIMEOUT + "\"";
     testlocaleTplDef.CustomBuildOut = "$(OutDir)\\runloctests.log";
 
     var testlocalesDef = testlocaleTplDef.createTestLocalesDef("%SRCDIR%\\etc\\nls");
@@ -424,15 +443,20 @@
                 var arrDeps = projectDef.PrjRefs.concat(projectDef.PrjDeps);
                 var command = "";
     
+                var cmdtpl = "set src=_SRC_\r\n" +
+                             "set dst=_DST_\r\n" +
+                             "if /I not %src%==%dst% (\r\n" +
+                             "if exist %src% (\r\n" +
+                             "del %dst%\r\n" +
+                             "copy /Y %src% %dst%\r\n" +
+                             "))";
+
                 if (0 <= arrayIndexOf(arrDeps, stdcxxDef))
                 {
                     var libname = "libstd%CONFIG%.dll";
                     var src = "\"" + libPath + "\\" + libname + "\"";
                     var dst = "\"$(OutDir)\\" + libname + "\"";
-                    var cmd = "if exist " + src + " (\r\n" +
-                              "del " + dst + "\r\n" +
-                              "copy /Y " + src + " " + dst + "\r\n" +
-                              ")";
+                    var cmd = cmdtpl.replace("_SRC_", src).replace("_DST_", dst);
                     if (0 == command.length)
                         command = cmd;
                     else
@@ -444,10 +468,7 @@
                     var libname = "rwtest.dll";
                     var src = "\"$(SolutionDir)%CONFIG%\\tests\\" + libname + "\"";
                     var dst = "\"$(OutDir)\\" + libname + "\"";
-                    var cmd = "if exist " + src + " (\r\n" +
-                              "del " + dst + "\r\n" +
-                              "copy /Y " + src + " " + dst + "\r\n" +
-                              ")";
+                    var cmd = cmdtpl.replace("_SRC_", src).replace("_DST_", dst);
                     if (0 == command.length)
                         command = cmd;
                     else
@@ -478,9 +499,9 @@
         {
             var projectDef = projectArray[j];
     
-            // turn on RTTI support if project in RTTIProjects array
-            if (0 <= arrayIndexOf(RTTIProjects, projectDef.Name))
-                projectDef.RTTI = true;
+            // turn off RTTI support if project in NonRTTIProjects array
+            if (0 <= arrayIndexOf(NonRTTIProjects, projectDef.Name))
+                projectDef.RTTI = false;
     
             projectDef.createVCProject(VCProjectEngine, report);
         }

Modified: incubator/stdcxx/branches/4.2.0/etc/config/windows/runall.wsf
URL: http://svn.apache.org/viewvc/incubator/stdcxx/branches/4.2.0/etc/config/windows/runall.wsf?rev=580483&r1=580482&r2=580483&view=diff
==============================================================================